# !/usr/bin/env/python
# -*- coding:utf-8 -*-


""" 
 Auth:  david <hsioe_david@aliyun.com>
 Date:  2020/11/09


 Desc
    Hsioe核心类
"""

from .core.logger import HsioeLogger
from .core.event import HsioeEvent
from .core.response import HsioeResponse
from .core.exception import HsioeException
import flask
import logging


class HsioeModules(object):
    """
    HsioeModules动态模块类
    """

    def __init__(self):
        object.__setattr__(self, 'modules', {})

    def __getattr__(self, name):

        if name in self.modules:
            return self.modules[name]

        return None

    def __setattr__(self, name, value):

        self.modules[name] = value


class HsioeFlask(object):
    """
    HsioeFlask核心类
    """

    #: HsioeFlaskResponse类型
    response = HsioeResponse

    #: HsioeException异常处理类
    exception = HsioeException

    #: HsioeLogger
    
    def __init__(self):
        #: 动态模块
        self.__modules = HsioeModules()

    @property
    def modules(self):
        return self.__modules

    def init(self, config):
        """
        HsioeFlask - Server
        基于Flask对象创建
        """
        self.__modules.server = flask.Flask('Hsioe')
        #: 读取配置文件
        self.__modules.server.config.from_object(config)

        # 装载事件
        self.load_event()
        # 装载日志
        self.load_logger()
        # 装载插件

    def load_event(self):
        """
        事件服务
        """
        self.__modules.event = HsioeEvent
    
    def load_logger(self):
        """
        日志服务
        """
        self.__modules.logger = HsioeLogger
    
    def load_plugins(self):
        """
        插件服务
        """
        pass

    def set_logger(self, log_name: str, log_path: str, level: str) -> None:
        """
        设置服务Logger
        """
        log = logging.getLogger(log_name)
        log_handler = HsioeLogger(log_name, log_path).log_handler
        log.addHandler(log_handler)
        log.setLevel(level)
        
        #: 添加到server日志对象
        attr_log_name = log_name + "_log"
        if not hasattr(self.__modules.server, attr_log_name):
            setattr(self.__modules.server, attr_log_name, log)



#!/usr/bin/env/python
# -*- coding:utf-8 -*-


""" 
 Auth:  david <hsioe_david@aliyun.com>
 Date:  


 Desc
    HsioeFlask 异常类
"""
from flask import request
from werkzeug.exceptions import HTTPException
from .response import HsioeResponse
import json


class HsioeException(HTTPException):
    """
    HsioeFlask异常类
    """

    #: 默认状态返回码
    status_code = 200
    #: 默认错误消息
    status_msg = 'ServerError'
    #: 默认业务code
    error_code = 80001

    def __init__(self, error_code=None, status_code=None, error_msg=None, payload=None):
        """
        初始化
        """
        self.code = status_code or self.status_code
        self.error_code = error_code or self.error_code
        self.status_msg = error_msg or self.error_msg
        self.payload = payload
        super(HsioeException, self).__init__(self.status_msg, None)
    
    def get_body(self, environ=None):
        """
        返回异常内容体
        """
        self.payload = {
            'api': request.method + '' + request.path
        }
        response = HsioeResponse(
            code=self.error_code, 
            message=self.status_msg,
            data=self.payload
        )
        return json.dumps(response.response_data)

    def get_headers(self, environ=None):
        """
        异常响应头
        """
        return [('Content-Type', 'application/json')]



# !/usr/bin/env/python
# -*- coding:utf-8 -*-


""" 
 Auth:  david <hsioe_david@aliyun.com>
 Date:  2020/11/10


 Desc
    HsioeFlask version 0.0.1 打包
"""

import setuptools

with open("README.md", "r", encoding='utf-8') as f:
    long_description = f.read()

setuptools.setup(
    name='HsioeFlask',
    version='0.0.1',
    keywords='Flask, Hsioe, Web',
    author='hsioe',
    author_email='hsioe_david@aliyun.com',
    description='A Simple Flask Business Api Frame!',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=['hsioe', 'hsioe/core'],
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'flask==1.1.4',
        'flask-restplus==*',
        'cached-property==*',
        'werkzeug==0.15.0'
    ]
)
1